==> mx-locale_24.5.02.tar.xz: BUILD/translations/mx-locale_sv.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Program_Name</source>
        <translation>Program_Namn</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="46"/>
        <source>Quit application</source>
        <translation>Avsluta programmet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="49"/>
        <source>Close</source>
        <translation>Stäng</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="55"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="93"/>
        <source>About this application</source>
        <translation>Om detta program</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="96"/>
        <source>About...</source>
        <translation>Om...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="102"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="118"/>
        <source>Display help </source>
        <translation>Visa hjälp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="121"/>
        <source>Help</source>
        <translation>Hjälp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="127"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <source>System Locale</source>
        <extracomment> language selection, also default for locale subvariables if not otherwise defined</extracomment>
        <translation type="vanished">Systemspråk-inställningar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="214"/>
        <source>PushButton</source>
        <translation>Knapp att trycka på</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="207"/>
        <source>Current System Language:</source>
        <translation>Nuvarande Systemspråk.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="181"/>
        <source>System Language</source>
        <extracomment> language selection, also default for locale subvariables if not otherwise defined</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="187"/>
        <source>Set all locale categories to current language</source>
        <translation>Ställ in alla språkkategorier på nuvarande språk</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="229"/>
        <source>Locale Categories</source>
        <extracomment>defines individual subvariables for locale</extracomment>
        <translation>Språkkategorier</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="255"/>
        <source>Numeric</source>
        <translation>Numerisk</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="269"/>
        <source>Time</source>
        <translation>Tid</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="283"/>
        <source>Collate</source>
        <translation>Jämför</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="297"/>
        <source>Currency</source>
        <translation>Valuta</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="311"/>
        <source>Messages</source>
        <translation>Meddelanden</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="325"/>
        <source>Paper Size</source>
        <translation>Pappersstorlek</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="339"/>
        <source>Name Style</source>
        <translation>Namnstil</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="353"/>
        <source>Address</source>
        <translation>Adress</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="367"/>
        <source>Telephone</source>
        <translation>Telefon</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="381"/>
        <source>Measurement</source>
        <translation>Mått</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="413"/>
        <source>Locale Management</source>
        <extracomment>Tab to manage generation of locale caches</extracomment>
        <translation>Språkhantering</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="465"/>
        <location filename="../mainwindow.ui" line="469"/>
        <location filename="../mainwindow.cpp" line="341"/>
        <source>All</source>
        <extracomment>elements of filter box</extracomment>
        <translation>Alla</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="474"/>
        <location filename="../mainwindow.cpp" line="291"/>
        <source>Enabled</source>
        <translation>Aktiverad</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="479"/>
        <location filename="../mainwindow.cpp" line="290"/>
        <source>Disabled</source>
        <translation>Avaktiverad</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="445"/>
        <source>Disable all locales except the one in use</source>
        <extracomment>disables generation of any locale except on that is currently in use</extracomment>
        <translation>Stäng av alla språk utom det som används</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="428"/>
        <source>search</source>
        <translation>sök</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="455"/>
        <source>Reset locale list to default</source>
        <translation>Återställ språklistan till standard</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="221"/>
        <source>Remove MX manuals for languages other than system default</source>
        <translation>Ta bort MX manualer för andra språk än systemstandard</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="498"/>
        <source>Changes go into effect on login</source>
        <translation>Ändringarna genomförs vid inloggning</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="74"/>
        <source>MX Locale</source>
        <translation>MX Språk</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="142"/>
        <source>About %1</source>
        <translation>Om %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="144"/>
        <source>Version: </source>
        <translation>Version:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="145"/>
        <source>Program for changing language and locale categories</source>
        <translation>Program för att byta språk och språkinställningskategorier</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="149"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="150"/>
        <source>%1 License</source>
        <translation>%1 Licens</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="157"/>
        <source>%1 Help</source>
        <translation>%1 Hjälp</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="261"/>
        <source>Locale in use: &lt;b&gt;%1&lt;/b&gt;</source>
        <comment>shows the current system locale, in bold</comment>
        <translation>Använt språk: &lt;b&gt;%1&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="283"/>
        <location filename="../mainwindow.cpp" line="289"/>
        <source>All</source>
        <comment>all as in everything</comment>
        <translation>Alla</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="306"/>
        <location filename="../mainwindow.cpp" line="352"/>
        <location filename="../mainwindow.cpp" line="358"/>
        <location filename="../mainwindow.cpp" line="364"/>
        <source>Error</source>
        <translation>Fel</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="307"/>
        <source>Can&apos;t disable locale in use</source>
        <comment>message that the chosen locale cannot be disabled because it is in active usage</comment>
        <translation>Kan inte stänga av använda språkinställningar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="339"/>
        <source>Locales enabled: %1</source>
        <comment>label for a numerical count of enabled and available locales</comment>
        <translation>Aktiverade språkinställningar: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="352"/>
        <location filename="../mainwindow.cpp" line="358"/>
        <location filename="../mainwindow.cpp" line="364"/>
        <source>Could not open %1</source>
        <translation>Kunde inte öppna %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="392"/>
        <source>Locales enabled: %1</source>
        <translation>Aktiverade språkinställningar: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="401"/>
        <source>Updating locales, please wait</source>
        <translation>Uppdaterar språkfiler, var vänlig vänta</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="447"/>
        <source>Removing packages, please wait</source>
        <translation>Tar bort paket, var vänlig vänta</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="35"/>
        <source>License</source>
        <translation>Licens</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="36"/>
        <location filename="../about.cpp" line="46"/>
        <source>Changelog</source>
        <translation>Ändringslogg</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="37"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="55"/>
        <source>&amp;Close</source>
        <translation>&amp;Stäng</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="57"/>
        <source>MX Locale is a tool used for managing locale settings in MX Linux</source>
        <translation>MX Språkinställningar är ett verktyg för att hantera språkinställningar i  MX Linux</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="60"/>
        <source>Show only language selection tab.</source>
        <translation>Visa enbart språkvalsfliken.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="61"/>
        <source>Show all locale categories.</source>
        <translation>Visa alla språkinställningskategorier.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="71"/>
        <location filename="../main.cpp" line="79"/>
        <source>Error</source>
        <translation>Fel</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="72"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Du verkar vara inloggad som rot, var vänlig logga ut och logga in som vanlig användare för att använda detta program.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="80"/>
        <source>You must run this program with admin access.</source>
        <translation>Du måste köra detta program med administratörsrättigheter.</translation>
    </message>
</context>
<context>
    <name>chooseDialog</name>
    <message>
        <location filename="../choosedialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <location filename="../choosedialog.ui" line="48"/>
        <source>search</source>
        <translation>sök</translation>
    </message>
    <message>
        <location filename="../choosedialog.ui" line="58"/>
        <source>If your desired language is not listed here, enable it in &quot;Locale management&quot; tab</source>
        <translation>Om språket du vill ha inte är listat här, aktivera det i &quot;Språkhanterings&quot; fliken</translation>
    </message>
    <message>
        <location filename="../choosedialog.cpp" line="25"/>
        <source>MX Locale</source>
        <comment>name of application</comment>
        <translation>MX Språk</translation>
    </message>
    <message>
        <location filename="../choosedialog.cpp" line="40"/>
        <source>Error</source>
        <translation>Fel</translation>
    </message>
    <message>
        <location filename="../choosedialog.cpp" line="41"/>
        <source>Could not open %1</source>
        <comment>message that a file could not be open, file takes place of %1</comment>
        <translation>Kunde inte öppna %1</translation>
    </message>
</context>
</TS>

==> mx-locale_25.4.tar.xz: BUILD/translations/mx-locale_sv.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Program_Name</source>
        <translation>Program_Namn</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="46"/>
        <source>Quit application</source>
        <translation>Avsluta programmet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="49"/>
        <source>Close</source>
        <translation>Stäng</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="55"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="93"/>
        <source>About this application</source>
        <translation>Om detta program</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="96"/>
        <source>About...</source>
        <translation>Om...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="102"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="118"/>
        <source>Display help </source>
        <translation>Visa hjälp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="121"/>
        <source>Help</source>
        <translation>Hjälp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="127"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="214"/>
        <source>PushButton</source>
        <translation>Knapp att trycka på</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="207"/>
        <source>Current System Language:</source>
        <translation>Nuvarande Systemspråk.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="181"/>
        <source>System Language</source>
        <extracomment> language selection, also default for locale subvariables if not otherwise defined</extracomment>
        <translation>Systemspråk</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="187"/>
        <source>Set all locale categories to current language</source>
        <translation>Ställ in alla språkkategorier på nuvarande språk</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="229"/>
        <source>Locale Categories</source>
        <extracomment>defines individual subvariables for locale</extracomment>
        <translation>Språkkategorier</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="255"/>
        <source>Numeric</source>
        <translation>Numerisk</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="269"/>
        <source>Time</source>
        <translation>Tid</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="283"/>
        <source>Collate</source>
        <translation>Jämför</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="297"/>
        <source>Currency</source>
        <translation>Valuta</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="311"/>
        <source>Messages</source>
        <translation>Meddelanden</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="325"/>
        <source>Paper Size</source>
        <translation>Pappersstorlek</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="339"/>
        <source>Name Style</source>
        <translation>Namnstil</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="353"/>
        <source>Address</source>
        <translation>Adress</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="367"/>
        <source>Telephone</source>
        <translation>Telefon</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="381"/>
        <source>Measurement</source>
        <translation>Mått</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="413"/>
        <source>Locale Management</source>
        <extracomment>Tab to manage generation of locale caches</extracomment>
        <translation>Språkhantering</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="465"/>
        <location filename="../mainwindow.ui" line="469"/>
        <location filename="../mainwindow.cpp" line="352"/>
        <source>All</source>
        <extracomment>elements of filter box</extracomment>
        <translation>Alla</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="474"/>
        <location filename="../mainwindow.cpp" line="293"/>
        <source>Enabled</source>
        <translation>Aktiverad</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="479"/>
        <location filename="../mainwindow.cpp" line="292"/>
        <source>Disabled</source>
        <translation>Avaktiverad</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="445"/>
        <source>Disable all locales except the one in use</source>
        <extracomment>disables generation of any locale except on that is currently in use</extracomment>
        <translation>Stäng av alla språk utom det som används</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="428"/>
        <source>search</source>
        <translation>sök</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="455"/>
        <source>Reset locale list to default</source>
        <translation>Återställ språklistan till standard</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="221"/>
        <source>Remove MX manuals for languages other than system default</source>
        <translation>Ta bort MX manualer för andra språk än systemstandard</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="498"/>
        <source>Changes go into effect on login</source>
        <translation>Ändringarna genomförs vid inloggning</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="79"/>
        <source>MX Locale</source>
        <translation>MX Språk</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="153"/>
        <source>About %1</source>
        <translation>Om %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="155"/>
        <source>Version: </source>
        <translation>Version:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="156"/>
        <source>Program for changing language and locale categories</source>
        <translation>Program för att byta språk och språkinställningskategorier</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="160"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="161"/>
        <source>%1 License</source>
        <translation>%1 Licens</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="168"/>
        <source>%1 Help</source>
        <translation>%1 Hjälp</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="267"/>
        <source>Locale in use: &lt;b&gt;%1&lt;/b&gt;</source>
        <comment>shows the current system locale, in bold</comment>
        <translation>Använt språk: &lt;b&gt;%1&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="283"/>
        <source>All</source>
        <comment>all as in everything</comment>
        <translation>Alla</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="318"/>
        <location filename="../mainwindow.cpp" line="375"/>
        <location filename="../mainwindow.cpp" line="390"/>
        <source>Error</source>
        <translation>Fel</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="319"/>
        <source>Can&apos;t disable locale in use</source>
        <comment>message that the chosen locale cannot be disabled because it is in active usage</comment>
        <translation>Kan inte stänga av använda språkinställningar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="350"/>
        <source>Locales enabled: %1</source>
        <comment>label for a numerical count of enabled and available locales</comment>
        <translation>Aktiverade språkinställningar: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="375"/>
        <location filename="../mainwindow.cpp" line="390"/>
        <source>Could not open %1</source>
        <translation>Kunde inte öppna %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="459"/>
        <source>Locales enabled: %1</source>
        <translation>Aktiverade språkinställningar: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="468"/>
        <source>Updating locales, please wait</source>
        <translation>Uppdaterar språkfiler, var vänlig vänta</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="519"/>
        <source>Remove Manuals</source>
        <translation>Ta bort Manualer</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="519"/>
        <source>No manuals to remove.</source>
        <translation>Inga manualer att ta bort.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="526"/>
        <source>Removing packages, please wait</source>
        <translation>Tar bort paket, var vänlig vänta</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="70"/>
        <source>License</source>
        <translation>Licens</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="71"/>
        <location filename="../about.cpp" line="81"/>
        <source>Changelog</source>
        <translation>Ändringslogg</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="72"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="94"/>
        <source>&amp;Close</source>
        <translation>&amp;Stäng</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="68"/>
        <source>MX Locale is a tool used for managing locale settings in MX Linux</source>
        <translation>MX Språkinställningar är ett verktyg för att hantera språkinställningar i  MX Linux</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="71"/>
        <source>Show only language selection tab.</source>
        <translation>Visa enbart språkvalsfliken.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="72"/>
        <source>Show all locale categories.</source>
        <translation>Visa alla språkinställningskategorier.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="82"/>
        <location filename="../main.cpp" line="90"/>
        <source>Error</source>
        <translation>Fel</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="83"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Du verkar vara inloggad som rot, var vänlig logga ut och logga in som vanlig användare för att använda detta program.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="91"/>
        <source>You must run this program with admin access.</source>
        <translation>Du måste köra detta program med administratörsrättigheter.</translation>
    </message>
</context>
<context>
    <name>chooseDialog</name>
    <message>
        <location filename="../choosedialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <location filename="../choosedialog.ui" line="48"/>
        <source>search</source>
        <translation>sök</translation>
    </message>
    <message>
        <location filename="../choosedialog.ui" line="58"/>
        <source>If your desired language is not listed here, enable it in &quot;Locale management&quot; tab</source>
        <translation>Om språket du vill ha inte är listat här, aktivera det i &quot;Språkhanterings&quot; fliken</translation>
    </message>
    <message>
        <location filename="../choosedialog.cpp" line="25"/>
        <source>MX Locale</source>
        <comment>name of application</comment>
        <translation>MX Språk</translation>
    </message>
    <message>
        <location filename="../choosedialog.cpp" line="40"/>
        <source>Error</source>
        <translation>Fel</translation>
    </message>
    <message>
        <location filename="../choosedialog.cpp" line="41"/>
        <source>Could not open %1</source>
        <comment>message that a file could not be opened, file takes place of %1</comment>
        <translation type="unfinished">Kunde inte öppna %1</translation>
    </message>
    <message>
        <source>Could not open %1</source>
        <comment>message that a file could not be open, file takes place of %1</comment>
        <translation type="vanished">Kunde inte öppna %1</translation>
    </message>
</context>
</TS>
